aboutsummaryrefslogtreecommitdiffstats
path: root/python/fatcat_client
diff options
context:
space:
mode:
authorBryan Newbold <bnewbold@robocracy.org>2018-07-25 14:41:02 -0700
committerBryan Newbold <bnewbold@robocracy.org>2018-07-25 14:41:02 -0700
commit829765848a57190a7bb7fd4ff985f49d61055e97 (patch)
tree43c226712abaa8089324e25142f5e6448c634bda /python/fatcat_client
parent828deb42b6dbdb2d11527e073d96bde26d8fb979 (diff)
downloadfatcat-829765848a57190a7bb7fd4ff985f49d61055e97.tar.gz
fatcat-829765848a57190a7bb7fd4ff985f49d61055e97.zip
update python codegen library
Diffstat (limited to 'python/fatcat_client')
-rw-r--r--python/fatcat_client/__init__.py2
-rw-r--r--python/fatcat_client/models/__init__.py2
-rw-r--r--python/fatcat_client/models/container_entity.py28
-rw-r--r--python/fatcat_client/models/creator_entity.py28
-rw-r--r--python/fatcat_client/models/entity_edit.py28
-rw-r--r--python/fatcat_client/models/file_entity.py36
-rw-r--r--python/fatcat_client/models/file_entity_urls.py140
-rw-r--r--python/fatcat_client/models/release_contrib.py56
-rw-r--r--python/fatcat_client/models/release_entity.py107
-rw-r--r--python/fatcat_client/models/release_entity_abstracts.py190
-rw-r--r--python/fatcat_client/models/release_ref.py34
-rw-r--r--python/fatcat_client/models/work_entity.py28
12 files changed, 599 insertions, 80 deletions
diff --git a/python/fatcat_client/__init__.py b/python/fatcat_client/__init__.py
index fca893a7..863892e6 100644
--- a/python/fatcat_client/__init__.py
+++ b/python/fatcat_client/__init__.py
@@ -32,8 +32,10 @@ from fatcat_client.models.entity_edit import EntityEdit
from fatcat_client.models.entity_history_entry import EntityHistoryEntry
from fatcat_client.models.error_response import ErrorResponse
from fatcat_client.models.file_entity import FileEntity
+from fatcat_client.models.file_entity_urls import FileEntityUrls
from fatcat_client.models.release_contrib import ReleaseContrib
from fatcat_client.models.release_entity import ReleaseEntity
+from fatcat_client.models.release_entity_abstracts import ReleaseEntityAbstracts
from fatcat_client.models.release_ref import ReleaseRef
from fatcat_client.models.stats_response import StatsResponse
from fatcat_client.models.success import Success
diff --git a/python/fatcat_client/models/__init__.py b/python/fatcat_client/models/__init__.py
index e09fe3e4..fb0f9ab1 100644
--- a/python/fatcat_client/models/__init__.py
+++ b/python/fatcat_client/models/__init__.py
@@ -25,8 +25,10 @@ from fatcat_client.models.entity_edit import EntityEdit
from fatcat_client.models.entity_history_entry import EntityHistoryEntry
from fatcat_client.models.error_response import ErrorResponse
from fatcat_client.models.file_entity import FileEntity
+from fatcat_client.models.file_entity_urls import FileEntityUrls
from fatcat_client.models.release_contrib import ReleaseContrib
from fatcat_client.models.release_entity import ReleaseEntity
+from fatcat_client.models.release_entity_abstracts import ReleaseEntityAbstracts
from fatcat_client.models.release_ref import ReleaseRef
from fatcat_client.models.stats_response import StatsResponse
from fatcat_client.models.success import Success
diff --git a/python/fatcat_client/models/container_entity.py b/python/fatcat_client/models/container_entity.py
index 967b6de0..0d8dffef 100644
--- a/python/fatcat_client/models/container_entity.py
+++ b/python/fatcat_client/models/container_entity.py
@@ -33,6 +33,7 @@ class ContainerEntity(object):
swagger_types = {
'coden': 'str',
'abbrev': 'str',
+ 'wikidata_qid': 'str',
'issnl': 'str',
'publisher': 'str',
'name': 'str',
@@ -47,6 +48,7 @@ class ContainerEntity(object):
attribute_map = {
'coden': 'coden',
'abbrev': 'abbrev',
+ 'wikidata_qid': 'wikidata_qid',
'issnl': 'issnl',
'publisher': 'publisher',
'name': 'name',
@@ -58,11 +60,12 @@ class ContainerEntity(object):
'state': 'state'
}
- def __init__(self, coden=None, abbrev=None, issnl=None, publisher=None, name=None, extra=None, editgroup_id=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
+ def __init__(self, coden=None, abbrev=None, wikidata_qid=None, issnl=None, publisher=None, name=None, extra=None, editgroup_id=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
"""ContainerEntity - a model defined in Swagger""" # noqa: E501
self._coden = None
self._abbrev = None
+ self._wikidata_qid = None
self._issnl = None
self._publisher = None
self._name = None
@@ -78,6 +81,8 @@ class ContainerEntity(object):
self.coden = coden
if abbrev is not None:
self.abbrev = abbrev
+ if wikidata_qid is not None:
+ self.wikidata_qid = wikidata_qid
if issnl is not None:
self.issnl = issnl
if publisher is not None:
@@ -139,6 +144,27 @@ class ContainerEntity(object):
self._abbrev = abbrev
@property
+ def wikidata_qid(self):
+ """Gets the wikidata_qid of this ContainerEntity. # noqa: E501
+
+
+ :return: The wikidata_qid of this ContainerEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._wikidata_qid
+
+ @wikidata_qid.setter
+ def wikidata_qid(self, wikidata_qid):
+ """Sets the wikidata_qid of this ContainerEntity.
+
+
+ :param wikidata_qid: The wikidata_qid of this ContainerEntity. # noqa: E501
+ :type: str
+ """
+
+ self._wikidata_qid = wikidata_qid
+
+ @property
def issnl(self):
"""Gets the issnl of this ContainerEntity. # noqa: E501
diff --git a/python/fatcat_client/models/creator_entity.py b/python/fatcat_client/models/creator_entity.py
index ac221f97..fa6f8619 100644
--- a/python/fatcat_client/models/creator_entity.py
+++ b/python/fatcat_client/models/creator_entity.py
@@ -31,6 +31,7 @@ class CreatorEntity(object):
and the value is json key in definition.
"""
swagger_types = {
+ 'wikidata_qid': 'str',
'orcid': 'str',
'surname': 'str',
'given_name': 'str',
@@ -44,6 +45,7 @@ class CreatorEntity(object):
}
attribute_map = {
+ 'wikidata_qid': 'wikidata_qid',
'orcid': 'orcid',
'surname': 'surname',
'given_name': 'given_name',
@@ -56,9 +58,10 @@ class CreatorEntity(object):
'extra': 'extra'
}
- def __init__(self, orcid=None, surname=None, given_name=None, display_name=None, state=None, ident=None, revision=None, redirect=None, editgroup_id=None, extra=None): # noqa: E501
+ def __init__(self, wikidata_qid=None, orcid=None, surname=None, given_name=None, display_name=None, state=None, ident=None, revision=None, redirect=None, editgroup_id=None, extra=None): # noqa: E501
"""CreatorEntity - a model defined in Swagger""" # noqa: E501
+ self._wikidata_qid = None
self._orcid = None
self._surname = None
self._given_name = None
@@ -71,6 +74,8 @@ class CreatorEntity(object):
self._extra = None
self.discriminator = None
+ if wikidata_qid is not None:
+ self.wikidata_qid = wikidata_qid
if orcid is not None:
self.orcid = orcid
if surname is not None:
@@ -92,6 +97,27 @@ class CreatorEntity(object):
self.extra = extra
@property
+ def wikidata_qid(self):
+ """Gets the wikidata_qid of this CreatorEntity. # noqa: E501
+
+
+ :return: The wikidata_qid of this CreatorEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._wikidata_qid
+
+ @wikidata_qid.setter
+ def wikidata_qid(self, wikidata_qid):
+ """Sets the wikidata_qid of this CreatorEntity.
+
+
+ :param wikidata_qid: The wikidata_qid of this CreatorEntity. # noqa: E501
+ :type: str
+ """
+
+ self._wikidata_qid = wikidata_qid
+
+ @property
def orcid(self):
"""Gets the orcid of this CreatorEntity. # noqa: E501
diff --git a/python/fatcat_client/models/entity_edit.py b/python/fatcat_client/models/entity_edit.py
index d2d17d85..27af5eb6 100644
--- a/python/fatcat_client/models/entity_edit.py
+++ b/python/fatcat_client/models/entity_edit.py
@@ -34,6 +34,7 @@ class EntityEdit(object):
'edit_id': 'int',
'ident': 'str',
'revision': 'str',
+ 'prev_revision': 'str',
'redirect_ident': 'str',
'editgroup_id': 'str',
'extra': 'object'
@@ -43,17 +44,19 @@ class EntityEdit(object):
'edit_id': 'edit_id',
'ident': 'ident',
'revision': 'revision',
+ 'prev_revision': 'prev_revision',
'redirect_ident': 'redirect_ident',
'editgroup_id': 'editgroup_id',
'extra': 'extra'
}
- def __init__(self, edit_id=None, ident=None, revision=None, redirect_ident=None, editgroup_id=None, extra=None): # noqa: E501
+ def __init__(self, edit_id=None, ident=None, revision=None, prev_revision=None, redirect_ident=None, editgroup_id=None, extra=None): # noqa: E501
"""EntityEdit - a model defined in Swagger""" # noqa: E501
self._edit_id = None
self._ident = None
self._revision = None
+ self._prev_revision = None
self._redirect_ident = None
self._editgroup_id = None
self._extra = None
@@ -63,6 +66,8 @@ class EntityEdit(object):
self.ident = ident
if revision is not None:
self.revision = revision
+ if prev_revision is not None:
+ self.prev_revision = prev_revision
if redirect_ident is not None:
self.redirect_ident = redirect_ident
self.editgroup_id = editgroup_id
@@ -137,6 +142,27 @@ class EntityEdit(object):
self._revision = revision
@property
+ def prev_revision(self):
+ """Gets the prev_revision of this EntityEdit. # noqa: E501
+
+
+ :return: The prev_revision of this EntityEdit. # noqa: E501
+ :rtype: str
+ """
+ return self._prev_revision
+
+ @prev_revision.setter
+ def prev_revision(self, prev_revision):
+ """Sets the prev_revision of this EntityEdit.
+
+
+ :param prev_revision: The prev_revision of this EntityEdit. # noqa: E501
+ :type: str
+ """
+
+ self._prev_revision = prev_revision
+
+ @property
def redirect_ident(self):
"""Gets the redirect_ident of this EntityEdit. # noqa: E501
diff --git a/python/fatcat_client/models/file_entity_urls.py b/python/fatcat_client/models/file_entity_urls.py
new file mode 100644
index 00000000..6b6b0fda
--- /dev/null
+++ b/python/fatcat_client/models/file_entity_urls.py
@@ -0,0 +1,140 @@
+# coding: utf-8
+
+"""
+ fatcat
+
+ A scalable, versioned, API-oriented catalog of bibliographic entities and file metadata # noqa: E501
+
+ OpenAPI spec version: 0.1.0
+
+ Generated by: https://github.com/swagger-api/swagger-codegen.git
+"""
+
+
+import pprint
+import re # noqa: F401
+
+import six
+
+
+class FileEntityUrls(object):
+ """NOTE: This class is auto generated by the swagger code generator program.
+
+ Do not edit the class manually.
+ """
+
+ """
+ Attributes:
+ swagger_types (dict): The key is attribute name
+ and the value is attribute type.
+ attribute_map (dict): The key is attribute name
+ and the value is json key in definition.
+ """
+ swagger_types = {
+ 'url': 'str',
+ 'rel': 'str'
+ }
+
+ attribute_map = {
+ 'url': 'url',
+ 'rel': 'rel'
+ }
+
+ def __init__(self, url=None, rel=None): # noqa: E501
+ """FileEntityUrls - a model defined in Swagger""" # noqa: E501
+
+ self._url = None
+ self._rel = None
+ self.discriminator = None
+
+ self.url = url
+ self.rel = rel
+
+ @property
+ def url(self):
+ """Gets the url of this FileEntityUrls. # noqa: E501
+
+
+ :return: The url of this FileEntityUrls. # noqa: E501
+ :rtype: str
+ """
+ return self._url
+
+ @url.setter
+ def url(self, url):
+ """Sets the url of this FileEntityUrls.
+
+
+ :param url: The url of this FileEntityUrls. # noqa: E501
+ :type: str
+ """
+ if url is None:
+ raise ValueError("Invalid value for `url`, must not be `None`") # noqa: E501
+
+ self._url = url
+
+ @property
+ def rel(self):
+ """Gets the rel of this FileEntityUrls. # noqa: E501
+
+
+ :return: The rel of this FileEntityUrls. # noqa: E501
+ :rtype: str
+ """
+ return self._rel
+
+ @rel.setter
+ def rel(self, rel):
+ """Sets the rel of this FileEntityUrls.
+
+
+ :param rel: The rel of this FileEntityUrls. # noqa: E501
+ :type: str
+ """
+ if rel is None:
+ raise ValueError("Invalid value for `rel`, must not be `None`") # noqa: E501
+
+ self._rel = rel
+
+ def to_dict(self):
+ """Returns the model properties as a dict"""
+ result = {}
+
+ for attr, _ in six.iteritems(self.swagger_types):
+ value = getattr(self, attr)
+ if isinstance(value, list):
+ result[attr] = list(map(
+ lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
+ value
+ ))
+ elif hasattr(value, "to_dict"):
+ result[attr] = value.to_dict()
+ elif isinstance(value, dict):
+ result[attr] = dict(map(
+ lambda item: (item[0], item[1].to_dict())
+ if hasattr(item[1], "to_dict") else item,
+ value.items()
+ ))
+ else:
+ result[attr] = value
+
+ return result
+
+ def to_str(self):
+ """Returns the string representation of the model"""
+ return pprint.pformat(self.to_dict())
+
+ def __repr__(self):
+ """For `print` and `pprint`"""
+ return self.to_str()
+
+ def __eq__(self, other):
+ """Returns true if both objects are equal"""
+ if not isinstance(other, FileEntityUrls):
+ return False
+
+ return self.__dict__ == other.__dict__
+
+ def __ne__(self, other):
+ """Returns true if both objects are not equal"""
+ return not self == other
diff --git a/python/fatcat_client/models/release_entity.py b/python/fatcat_client/models/release_entity.py
index 2c5f273d..07b1cd80 100644
--- a/python/fatcat_client/models/release_entity.py
+++ b/python/fatcat_client/models/release_entity.py
@@ -17,6 +17,7 @@ import re # noqa: F401
import six
from fatcat_client.models.release_contrib import ReleaseContrib # noqa: F401,E501
+from fatcat_client.models.release_entity_abstracts import ReleaseEntityAbstracts # noqa: F401,E501
from fatcat_client.models.release_ref import ReleaseRef # noqa: F401,E501
@@ -34,6 +35,7 @@ class ReleaseEntity(object):
and the value is json key in definition.
"""
swagger_types = {
+ 'abstracts': 'list[ReleaseEntityAbstracts]',
'refs': 'list[ReleaseRef]',
'contribs': 'list[ReleaseContrib]',
'language': 'str',
@@ -41,6 +43,9 @@ class ReleaseEntity(object):
'pages': 'str',
'issue': 'str',
'volume': 'str',
+ 'wikidata_qid': 'str',
+ 'pmcid': 'str',
+ 'pmid': 'str',
'isbn13': 'str',
'doi': 'str',
'release_date': 'date',
@@ -58,6 +63,7 @@ class ReleaseEntity(object):
}
attribute_map = {
+ 'abstracts': 'abstracts',
'refs': 'refs',
'contribs': 'contribs',
'language': 'language',
@@ -65,6 +71,9 @@ class ReleaseEntity(object):
'pages': 'pages',
'issue': 'issue',
'volume': 'volume',
+ 'wikidata_qid': 'wikidata_qid',
+ 'pmcid': 'pmcid',
+ 'pmid': 'pmid',
'isbn13': 'isbn13',
'doi': 'doi',
'release_date': 'release_date',
@@ -81,9 +90,10 @@ class ReleaseEntity(object):
'extra': 'extra'
}
- def __init__(self, refs=None, contribs=None, language=None, publisher=None, pages=None, issue=None, volume=None, isbn13=None, doi=None, release_date=None, release_status=None, release_type=None, container_id=None, work_id=None, title=None, state=None, ident=None, revision=None, redirect=None, editgroup_id=None, extra=None): # noqa: E501
+ def __init__(self, abstracts=None, refs=None, contribs=None, language=None, publisher=None, pages=None, issue=None, volume=None, wikidata_qid=None, pmcid=None, pmid=None, isbn13=None, doi=None, release_date=None, release_status=None, release_type=None, container_id=None, work_id=None, title=None, state=None, ident=None, revision=None, redirect=None, editgroup_id=None, extra=None): # noqa: E501
"""ReleaseEntity - a model defined in Swagger""" # noqa: E501
+ self._abstracts = None
self._refs = None
self._contribs = None
self._language = None
@@ -91,6 +101,9 @@ class ReleaseEntity(object):
self._pages = None
self._issue = None
self._volume = None
+ self._wikidata_qid = None
+ self._pmcid = None
+ self._pmid = None
self._isbn13 = None
self._doi = None
self._release_date = None
@@ -107,6 +120,8 @@ class ReleaseEntity(object):
self._extra = None
self.discriminator = None
+ if abstracts is not None:
+ self.abstracts = abstracts
if refs is not None:
self.refs = refs
if contribs is not None:
@@ -121,6 +136,12 @@ class ReleaseEntity(object):
self.issue = issue
if volume is not None:
self.volume = volume
+ if wikidata_qid is not None:
+ self.wikidata_qid = wikidata_qid
+ if pmcid is not None:
+ self.pmcid = pmcid
+ if pmid is not None:
+ self.pmid = pmid
if isbn13 is not None:
self.isbn13 = isbn13
if doi is not None:
@@ -150,6 +171,27 @@ class ReleaseEntity(object):
self.extra = extra
@property
+ def abstracts(self):
+ """Gets the abstracts of this ReleaseEntity. # noqa: E501
+
+
+ :return: The abstracts of this ReleaseEntity. # noqa: E501
+ :rtype: list[ReleaseEntityAbstracts]
+ """
+ return self._abstracts
+
+ @abstracts.setter
+ def abstracts(self, abstracts):
+ """Sets the abstracts of this ReleaseEntity.
+
+
+ :param abstracts: The abstracts of this ReleaseEntity. # noqa: E501
+ :type: list[ReleaseEntityAbstracts]
+ """
+
+ self._abstracts = abstracts
+
+ @property
def refs(self):
"""Gets the refs of this ReleaseEntity. # noqa: E501
@@ -299,6 +341,69 @@ class ReleaseEntity(object):
self._volume = volume
@property
+ def wikidata_qid(self):
+ """Gets the wikidata_qid of this ReleaseEntity. # noqa: E501
+
+
+ :return: The wikidata_qid of this ReleaseEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._wikidata_qid
+
+ @wikidata_qid.setter
+ def wikidata_qid(self, wikidata_qid):
+ """Sets the wikidata_qid of this ReleaseEntity.
+
+
+ :param wikidata_qid: The wikidata_qid of this ReleaseEntity. # noqa: E501
+ :type: str
+ """
+
+ self._wikidata_qid = wikidata_qid
+
+ @property
+ def pmcid(self):
+ """Gets the pmcid of this ReleaseEntity. # noqa: E501
+
+
+ :return: The pmcid of this ReleaseEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._pmcid
+
+ @pmcid.setter
+ def pmcid(self, pmcid):
+ """Sets the pmcid of this ReleaseEntity.
+
+
+ :param pmcid: The pmcid of this ReleaseEntity. # noqa: E501
+ :type: str
+ """
+
+ self._pmcid = pmcid
+
+ @property
+ def pmid(self):
+ """Gets the pmid of this ReleaseEntity. # noqa: E501
+
+
+ :return: The pmid of this ReleaseEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._pmid
+
+ @pmid.setter
+ def pmid(self, pmid):
+ """Sets the pmid of this ReleaseEntity.
+
+
+ :param pmid: The pmid of this ReleaseEntity. # noqa: E501
+ :type: str
+ """
+
+ self._pmid = pmid
+
+ @property
def isbn13(self):
"""Gets the isbn13 of this ReleaseEntity. # noqa: E501
diff --git a/python/fatcat_client/models/release_entity_abstracts.py b/python/fatcat_client/models/release_entity_abstracts.py
new file mode 100644
index 00000000..1adf832a
--- /dev/null
+++ b/python/fatcat_client/models/release_entity_abstracts.py
@@ -0,0 +1,190 @@
+# coding: utf-8
+
+"""
+ fatcat
+
+ A scalable, versioned, API-oriented catalog of bibliographic entities and file metadata # noqa: E501
+
+ OpenAPI spec version: 0.1.0
+
+ Generated by: https://github.com/swagger-api/swagger-codegen.git
+"""
+
+
+import pprint
+import re # noqa: F401
+
+import six
+
+
+class ReleaseEntityAbstracts(object):
+ """NOTE: This class is auto generated by the swagger code generator program.
+
+ Do not edit the class manually.
+ """
+
+ """
+ Attributes:
+ swagger_types (dict): The key is attribute name
+ and the value is attribute type.
+ attribute_map (dict): The key is attribute name
+ and the value is json key in definition.
+ """
+ swagger_types = {
+ 'sha1': 'str',
+ 'content': 'str',
+ 'mimetype': 'str',
+ 'lang': 'str'
+ }
+
+ attribute_map = {
+ 'sha1': 'sha1',
+ 'content': 'content',
+ 'mimetype': 'mimetype',
+ 'lang': 'lang'
+ }
+
+ def __init__(self, sha1=None, content=None, mimetype=None, lang=None): # noqa: E501
+ """ReleaseEntityAbstracts - a model defined in Swagger""" # noqa: E501
+
+ self._sha1 = None
+ self._content = None
+ self._mimetype = None
+ self._lang = None
+ self.discriminator = None
+
+ if sha1 is not None:
+ self.sha1 = sha1
+ if content is not None:
+ self.content = content
+ if mimetype is not None:
+ self.mimetype = mimetype
+ if lang is not None:
+ self.lang = lang
+
+ @property
+ def sha1(self):
+ """Gets the sha1 of this ReleaseEntityAbstracts. # noqa: E501
+
+
+ :return: The sha1 of this ReleaseEntityAbstracts. # noqa: E501
+ :rtype: str
+ """
+ return self._sha1
+
+ @sha1.setter
+ def sha1(self, sha1):
+ """Sets the sha1 of this ReleaseEntityAbstracts.
+
+
+ :param sha1: The sha1 of this ReleaseEntityAbstracts. # noqa: E501
+ :type: str
+ """
+
+ self._sha1 = sha1
+
+ @property
+ def content(self):
+ """Gets the content of this ReleaseEntityAbstracts. # noqa: E501
+
+
+ :return: The content of this ReleaseEntityAbstracts. # noqa: E501
+ :rtype: str
+ """
+ return self._content
+
+ @content.setter
+ def content(self, content):
+ """Sets the content of this ReleaseEntityAbstracts.
+
+
+ :param content: The content of this ReleaseEntityAbstracts. # noqa: E501
+ :type: str
+ """
+
+ self._content = content
+
+ @property
+ def mimetype(self):
+ """Gets the mimetype of this ReleaseEntityAbstracts. # noqa: E501
+
+
+ :return: The mimetype of this ReleaseEntityAbstracts. # noqa: E501
+ :rtype: str
+ """
+ return self._mimetype
+
+ @mimetype.setter
+ def mimetype(self, mimetype):
+ """Sets the mimetype of this ReleaseEntityAbstracts.
+
+
+ :param mimetype: The mimetype of this ReleaseEntityAbstracts. # noqa: E501
+ :type: str
+ """
+
+ self._mimetype = mimetype
+
+ @property
+ def lang(self):
+ """Gets the lang of this ReleaseEntityAbstracts. # noqa: E501
+
+
+ :return: The lang of this ReleaseEntityAbstracts. # noqa: E501
+ :rtype: str
+ """
+ return self._lang
+
+ @lang.setter
+ def lang(self, lang):
+ """Sets the lang of this ReleaseEntityAbstracts.
+
+
+ :param lang: The lang of this ReleaseEntityAbstracts. # noqa: E501
+ :type: str
+ """
+
+ self._lang = lang
+
+ def to_dict(self):
+ """Returns the model properties as a dict"""
+ result = {}
+
+ for attr, _ in six.iteritems(self.swagger_types):
+ value = getattr(self, attr)
+ if isinstance(value, list):
+ result[attr] = list(map(
+ lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
+ value
+ ))
+ elif hasattr(value, "to_dict"):
+ result[attr] = value.to_dict()
+ elif isinstance(value, dict):
+ result[attr] = dict(map(
+ lambda item: (item[0], item[1].to_dict())
+ if hasattr(item[1], "to_dict") else item,
+ value.items()
+ ))
+ else:
+ result[attr] = value
+
+ return result
+
+ def to_str(self):
+ """Returns the string representation of the model"""
+ return pprint.pformat(self.to_dict())
+
+ def __repr__(self):
+ """For `print` and `pprint`"""
+ return self.to_str()
+
+ def __eq__(self, other):
+ """Returns true if both objects are equal"""
+ if not isinstance(other, ReleaseEntityAbstracts):
+ return False
+
+ return self.__dict__ == other.__dict__
+
+ def __ne__(self, other):
+ """Returns true if both objects are not equal"""
+ return not self == other
diff --git a/python/fatcat_client/models/work_entity.py b/python/fatcat_client/models/work_entity.py
index e1c9ebdf..ab7d933b 100644
--- a/python/fatcat_client/models/work_entity.py
+++ b/python/fatcat_client/models/work_entity.py
@@ -31,7 +31,6 @@ class WorkEntity(object):
and the value is json key in definition.
"""
swagger_types = {
- 'work_type': 'str',
'extra': 'object',
'editgroup_id': 'str',
'redirect': 'str',
@@ -41,7 +40,6 @@ class WorkEntity(object):
}
attribute_map = {
- 'work_type': 'work_type',
'extra': 'extra',
'editgroup_id': 'editgroup_id',
'redirect': 'redirect',
@@ -50,10 +48,9 @@ class WorkEntity(object):
'state': 'state'
}
- def __init__(self, work_type=None, extra=None, editgroup_id=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
+ def __init__(self, extra=None, editgroup_id=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
"""WorkEntity - a model defined in Swagger""" # noqa: E501
- self._work_type = None
self._extra = None
self._editgroup_id = None
self._redirect = None
@@ -62,8 +59,6 @@ class WorkEntity(object):
self._state = None
self.discriminator = None
- if work_type is not None:
- self.work_type = work_type
if extra is not None:
self.extra = extra
if editgroup_id is not None:
@@ -78,27 +73,6 @@ class WorkEntity(object):
self.state = state
@property
- def work_type(self):
- """Gets the work_type of this WorkEntity. # noqa: E501
-
-
- :return: The work_type of this WorkEntity. # noqa: E501
- :rtype: str
- """
- return self._work_type
-
- @work_type.setter
- def work_type(self, work_type):
- """Sets the work_type of this WorkEntity.
-
-
- :param work_type: The work_type of this WorkEntity. # noqa: E501
- :type: str
- """
-
- self._work_type = work_type
-
- @property
def extra(self):
"""Gets the extra of this WorkEntity. # noqa: E501
diff --git a/python/fatcat_client/models/file_entity.py b/python/fatcat_client/models/file_entity.py
index 41884248..f6f315c1 100644
--- a/python/fatcat_client/models/file_entity.py
+++ b/python/fatcat_client/models/file_entity.py
@@ -16,6 +16,8 @@ import re # noqa: F401
import six
+from fatcat_client.models.file_entity_urls import FileEntityUrls # noqa: F401,E501
+
class FileEntity(object):
"""NOTE: This class is auto generated by the swagger code generator program.
@@ -33,7 +35,7 @@ class FileEntity(object):
swagger_types = {
'releases': 'list[str]',
'mimetype': 'str',
- 'url': 'str',
+ 'urls': 'list[FileEntityUrls]',
'sha256': 'str',
'md5': 'str',
'sha1': 'str',
@@ -49,7 +51,7 @@ class FileEntity(object):
attribute_map = {
'releases': 'releases',
'mimetype': 'mimetype',
- 'url': 'url',
+ 'urls': 'urls',
'sha256': 'sha256',
'md5': 'md5',
'sha1': 'sha1',
@@ -62,12 +64,12 @@ class FileEntity(object):
'state': 'state'
}
- def __init__(self, releases=None, mimetype=None, url=None, sha256=None, md5=None, sha1=None, size=None, extra=None, editgroup_id=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
+ def __init__(self, releases=None, mimetype=None, urls=None, sha256=None, md5=None, sha1=None, size=None, extra=None, editgroup_id=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
"""FileEntity - a model defined in Swagger""" # noqa: E501
self._releases = None
self._mimetype = None
- self._url = None
+ self._urls = None
self._sha256 = None
self._md5 = None
self._sha1 = None
@@ -84,8 +86,8 @@ class FileEntity(object):
self.releases = releases
if mimetype is not None:
self.mimetype = mimetype
- if url is not None:
- self.url = url
+ if urls is not None:
+ self.urls = urls
if sha256 is not None:
self.sha256 = sha256
if md5 is not None:
@@ -150,25 +152,25 @@ class FileEntity(object):
self._mimetype = mimetype
@property
- def url(self):
- """Gets the url of this FileEntity. # noqa: E501
+ def urls(self):
+ """Gets the urls of this FileEntity. # noqa: E501
- :return: The url of this FileEntity. # noqa: E501
- :rtype: str
+ :return: The urls of this FileEntity. # noqa: E501
+ :rtype: list[FileEntityUrls]
"""
- return self._url
+ return self._urls
- @url.setter
- def url(self, url):
- """Sets the url of this FileEntity.
+ @urls.setter
+ def urls(self, urls):
+ """Sets the urls of this FileEntity.
- :param url: The url of this FileEntity. # noqa: E501
- :type: str
+ :param urls: The urls of this FileEntity. # noqa: E501
+ :type: list[FileEntityUrls]
"""
- self._url = url
+ self._urls = urls
@property
def sha256(self):
diff --git a/python/fatcat_client/models/release_contrib.py b/python/fatcat_client/models/release_contrib.py
index 72eeca1d..f2eeac8f 100644
--- a/python/fatcat_client/models/release_contrib.py
+++ b/python/fatcat_client/models/release_contrib.py
@@ -33,23 +33,26 @@ class ReleaseContrib(object):
swagger_types = {
'index': 'int',
'creator_id': 'str',
- 'raw': 'str',
+ 'raw_name': 'str',
+ 'extra': 'object',
'role': 'str'
}
attribute_map = {
'index': 'index',
'creator_id': 'creator_id',
- 'raw': 'raw',
+ 'raw_name': 'raw_name',
+ 'extra': 'extra',
'role': 'role'
}
- def __init__(self, index=None, creator_id=None, raw=None, role=None): # noqa: E501
+ def __init__(self, index=None, creator_id=None, raw_name=None, extra=None, role=None): # noqa: E501
"""ReleaseContrib - a model defined in Swagger""" # noqa: E501
self._index = None
self._creator_id = None
- self._raw = None
+ self._raw_name = None
+ self._extra = None
self._role = None
self.discriminator = None
@@ -57,8 +60,10 @@ class ReleaseContrib(object):
self.index = index
if creator_id is not None:
self.creator_id = creator_id
- if raw is not None:
- self.raw = raw
+ if raw_name is not None:
+ self.raw_name = raw_name
+ if extra is not None:
+ self.extra = extra
if role is not None:
self.role = role
@@ -105,25 +110,46 @@ class ReleaseContrib(object):
self._creator_id = creator_id
@property
- def raw(self):
- """Gets the raw of this ReleaseContrib. # noqa: E501
+ def raw_name(self):
+ """Gets the raw_name of this ReleaseContrib. # noqa: E501
- :return: The raw of this ReleaseContrib. # noqa: E501
+ :return: The raw_name of this ReleaseContrib. # noqa: E501
:rtype: str
"""
- return self._raw
+ return self._raw_name
- @raw.setter
- def raw(self, raw):
- """Sets the raw of this ReleaseContrib.
+ @raw_name.setter
+ def raw_name(self, raw_name):
+ """Sets the raw_name of this ReleaseContrib.
- :param raw: The raw of this ReleaseContrib. # noqa: E501
+ :param raw_name: The raw_name of this ReleaseContrib. # noqa: E501
:type: str
"""
- self._raw = raw
+ self._raw_name = raw_name
+
+ @property
+ def extra(self):
+ """Gets the extra of this ReleaseContrib. # noqa: E501
+
+
+ :return: The extra of this ReleaseContrib. # noqa: E501
+ :rtype: object
+ """
+ return self._extra
+
+ @extra.setter
+ def extra(self, extra):
+ """Sets the extra of this ReleaseContrib.
+
+
+ :param extra: The extra of this ReleaseContrib. # noqa: E501
+ :type: object
+ """
+
+ self._extra = extra
@property
def role(self):
diff --git a/python/fatcat_client/models/release_ref.py b/python/fatcat_client/models/release_ref.py
index 7e15900c..7f0ff1bf 100644
--- a/python/fatcat_client/models/release_ref.py
+++ b/python/fatcat_client/models/release_ref.py
@@ -33,7 +33,7 @@ class ReleaseRef(object):
swagger_types = {
'index': 'int',
'target_release_id': 'str',
- 'raw': 'str',
+ 'extra': 'object',
'key': 'str',
'year': 'int',
'container_title': 'str',
@@ -44,7 +44,7 @@ class ReleaseRef(object):
attribute_map = {
'index': 'index',
'target_release_id': 'target_release_id',
- 'raw': 'raw',
+ 'extra': 'extra',
'key': 'key',
'year': 'year',
'container_title': 'container_title',
@@ -52,12 +52,12 @@ class ReleaseRef(object):
'locator': 'locator'
}
- def __init__(self, index=None, target_release_id=None, raw=None, key=None, year=None, container_title=None, title=None, locator=None): # noqa: E501
+ def __init__(self, index=None, target_release_id=None, extra=None, key=None, year=None, container_title=None, title=None, locator=None): # noqa: E501
"""ReleaseRef - a model defined in Swagger""" # noqa: E501
self._index = None
self._target_release_id = None
- self._raw = None
+ self._extra = None
self._key = None
self._year = None
self._container_title = None
@@ -69,8 +69,8 @@ class ReleaseRef(object):
self.index = index
if target_release_id is not None:
self.target_release_id = target_release_id
- if raw is not None:
- self.raw = raw
+ if extra is not None:
+ self.extra = extra
if key is not None:
self.key = key
if year is not None:
@@ -125,25 +125,25 @@ class ReleaseRef(object):
self._target_release_id = target_release_id
@property
- def raw(self):
- """Gets the raw of this ReleaseRef. # noqa: E501
+ def extra(self):
+ """Gets the extra of this ReleaseRef. # noqa: E501
- :return: The raw of this ReleaseRef. # noqa: E501
- :rtype: str
+ :return: The extra of this ReleaseRef. # noqa: E501
+ :rtype: object
"""
- return self._raw
+ return self._extra
- @raw.setter
- def raw(self, raw):
- """Sets the raw of this ReleaseRef.
+ @extra.setter
+ def extra(self, extra):
+ """Sets the extra of this ReleaseRef.
- :param raw: The raw of this ReleaseRef. # noqa: E501
- :type: str
+ :param extra: The extra of this ReleaseRef. # noqa: E501
+ :type: object
"""
- self._raw = raw
+ self._extra = extra
@property
def key(self):